﻿using DataSharing.Share.Dtos;
using DataSharing.Share.Enums;
using MapsterMapper;
using Microsoft.Extensions.Logging;
using XF.Domain.Dependency;
using XF.Domain.Repository;

namespace DataSharing.SendTask
{
    /// <summary>
    /// 初始化推送数据
    /// </summary>
    public class InitPushDataService : IInitPushDataService, IScopeDependency
    {
        private readonly IMapper _mapper;
        private readonly ILogger<InitPushDataService> _logger;
        private readonly IRepository<DsSendTask> _dsSendTaskRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="logger"></param>
        /// <param name="dsSendTaskRepository"></param>
        public InitPushDataService(IMapper mapper,
            ILogger<InitPushDataService> logger,
            IRepository<DsSendTask> dsSendTaskRepository)
        {
            _mapper = mapper;
            _logger = logger;
            _dsSendTaskRepository = dsSendTaskRepository;
        }

        /// 初始化待推送数据
        /// </summary>
        /// <param name="taskType">任务类型</param>
        /// <param name="path">请求地址</param>
        /// <param name="request">请求参数</param>
        /// <param name="ProvinceNo">省编号</param>
        /// <param name="pathType"></param>
        /// <param name="cancellationToken"></param>
        /// <param name="httpMethod">请求方式</param>
        /// <param name="platformSource">推送平台</param>
        /// <param name="taskPriority">任务优先级(0:最低级别)</param>
        /// <param name="fileJson">附件</param>
        /// <returns></returns>
        public async Task<string> InitPushDataAsync(string taskType, string path, string request, string ProvinceNo,
            string httpMethod = "Post",
            EPlatformSource platformSource = EPlatformSource.Province,
            EPathType pathType = EPathType.Other,
            int taskPriority = 0,
            DateTime? GenerationTime = null,
            List<FileJson>? fileJson = null,
            CancellationToken cancellationToken = default)
        {
            //组装参数
            DsSendTask dsSendTask = new()
            {
                ProvinceNo = ProvinceNo,
                TaskPriority = taskPriority,
                TaskType = taskType,
                HttpMethod = httpMethod,
                Path = path,
                PlatformSource = platformSource,
                FileJson = fileJson,
                Request = request,
                GenerationTime = GenerationTime,
                PathType = pathType
            };
            return await _dsSendTaskRepository.AddAsync(dsSendTask, cancellationToken);
        }
    }
}
